@@ -1,9 +1,62 @@
 # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-# ~~~ TCGAretriever ver 1.10.1 ~~~
+# ~~~ TCGAretriever ver 1.10.3 ~~~
 # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
 
 
+#' Check Connection to the cBioPortal Server 
+#' 
+#' Performs a connection check to determine if the remote cBioPortal data 
+#' server is reachable and responsive.
+#' 
+#' @details 
+#' This function attempts to fetch cancer studies within a strict 2-second 
+#' time limit. If the function returns `FALSE`, it may indicate:
+#' \itemize{
+#'   \item The server is currently down for maintenance.
+#'   \item The user's internet connection is inactive or blocked by a firewall.
+#'   \item The connection speed is too slow to support reliable data retrieval 
+#'         for larger datasets.
+#' }
+#' 
+#' @return logical; `TRUE` if the system can connect and retrieve data 
+#' within the time limit, `FALSE` otherwise.
+#' 
+#' 
+#' @examples
+#' \dontrun{
+#' check_TCGAretriever_connection()
+#' } 
+#' 
+#' @author Damiano Fantini, \email{damiano.fantini@@gmail.com}
+#' @references 
+#' \url{https://www.data-pulse.com/dev_site/TCGAretriever/}
+#' 
+#' 
+#' @export
+check_TCGAretriever_connection <-function() {
+  
+  infx <- function(){
+    setTimeLimit(cpu = 2, elapsed = 2, transient = TRUE)
+    on.exit(expr = {
+      setTimeLimit(cpu = Inf, elapsed = Inf, transient = FALSE)
+    })
+    return(get_cancer_studies())
+  }
+  
+  out <- tryCatch(expr = {
+    ck1 <- infx()
+    as.logical(
+      !is.null(ck1) && is.data.frame(ck1) && 
+        ncol(ck1) > 1 && nrow(ck1) > 5)
+    
+    }, error = function(e) { FALSE })
+
+  return(as.logical(out))
+}
+
+  
+  
 #' Core Query Engine
 #' 
 #' Submit a query by getting or posting to the URL provided as argument 
